NLSL: File Members

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

- All
- Functions/Subroutines
- Variables
- Typedefs
- Macros

- a
- b
- c
- d
- e
- f
- g
- h
- i
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w
- x
- z

### - a -

- addprm() : addprm.f90
- alphaf() : stats.f90
- alphat() : stats.f90
- anxlk() : anxlk.f90
- arbsub() : testmods.f90
- array_err() : genio.c
- assgnc() : assgnc.f90

### - b -

- basisc() : basisc.f90
- basstt() : statc.f90
- bessi() : bessel.f90
- bessi0() : bessel.f90
- bessi1() : bessel.f90
- betacf() : stats.f90
- betai() : stats.f90
- bincof() : w3j.f90
- brent() : brent.f90

### - c -

- calcpt() : pltx.c
- calcul() : pltx.c
- caldlm() : caldlm.f90
- catchc() : catch.c
- ccrin1() : ccrints.f90
- ccrint() : ccrints.f90
- cd2km() : cd2km.f90
- cfs() : cfs.f90
- cgltri() : cgltri.f90
- chi() : stats.f90
- confc() : confc.f90
- convtc() : convtc.f90
- correl() : correl.f90
- corrl() : stats.f90
- covar() : covar.f90
- covrpt() : covrpt.f90
- cscg() : cscg.f90

### - d -

- datac() : datac.f90
- datstt() : statc.f90
- daxpy() : daxpy.f90
- dblint() : getdat.f90
- dchex() : dchex.f90
- dcopy() : dcopy.f90
- ddot() : ddot.f90
- deletc() : basisc.f90
- differnce() : pltx.c
- doevnt() : pltx.c
- drawln() : pltx.c
- drotg() : drotg.f90
- dtime() : dtime.c

### - e -

- enorm() : enorm.f90
- eprls() : eprls.f90

### - f -

- findmax() : pltx.c
- findmin() : pltx.c
- findzero() : pltx.c
- fitc() : fitc.f90
- fitl() : fitl.f90
- fitstt() : statc.f90
- fixc() : fixc.f90
- fmomnt() : fmomnt.f90
- four1() : ftfuns.f90
- fphi() : ordrpr.f90
- fs() : stats.f90
- fstplt() : pltx_dummy.c , pltx.c
- ftht() : ordrpr.f90
- ftoken() : strutl1.f90
- fu20() : ordrpr.f90
- fu20phi() : ordrpr.f90
- fz() : fz.f90

### - g -

- gammln() : stats.f90
- gammq() : stats.f90
- gcf() : stats.f90
- gconvl() : gconvl.f90
- getarray() : genio.c
- getasc() : getdat.f90
- getbin() : genio.c
- getdat() : getdat.f90
- getint() : genio.c
- getlin() : strutl1.f90
- getlinerec() : genio.c
- getprm() : setprm.f90
- getreal() : genio.c
- getrecsize() : genio.c
- getss() : assgnc.f90
- getstr() : pltx.c
- gettkn() : strutl1.f90
- getwndws() : pltx.c , pltx_dummy.c
- gser() : stats.f90

### - h -

- helpc() : helpc.f90
- hltchk() : lfun.f90

### - i -

- ill_arrayrec() : genio.c
- ill_linerec() : genio.c
- indtkn() : strutl1.f90
- ipar() : ipar.f90
- ipfind() : ipsfind.f90
- iroot() : setnm.f90
- isaxial() : tensym.f90
- isfind() : ipsfind.f90
- isisotr() : tensym.f90
- isrhomb() : tensym.f90
- itoken() : strutl1.f90
- itrim() : strutl2.f90
- ixlim() : setprm.f90

### - l -

- l1pfun() : l1pfun.f90
- lbasix() : lbasix.f90
- lcheck() : lcheck.f90
- letc() : letc.f90
- lfun() : lfun.f90
- lgrint() : lgrint.f90
- linchk() : helpc.f90
- linebc() : getdat.f90
- lmnls() : lmnls.f90
- lmpar() : lmpar.f90
- lprmpt() : lprmpt.c

### - m -

- matrll() : matrll.f90
- mnbrak() : mnbrak.f90
- momdls() : momdls.f90

### - n -

- ncspln() : getdat.f90
- nlsinit() : nlsl.f90
- nlsl() : nlsl.f90
- normlz() : getdat.f90

### - o -

- ordrpr() : ordrpr.f90

### - p -

- parc() : parc.f90
- pausex() : stats.f90
- pchi() : stats.f90
- pixary() : pltx.c
- plgndr() : plgndr.f90
- pmatrl() : pmatrl.f90
- pstvec() : pstvec.f90
- ptype() : setprm.f90
- putarray() : genio.c
- putary() : pltx.c
- putbin() : genio.c
- putint() : genio.c
- putlinerec() : genio.c
- putreal() : genio.c
- putrecsize() : genio.c

### - q -

- qrfac() : qrfac.f90
- qrsolv() : qrsolv.f90
- qtbvec() : qrutil.f90

### - r -

- realft() : ftfuns.f90
- residx() : stats.f90
- rmvprm() : rmvprm.f90
- rsolve() : qrutil.f90

### - s -

- scalec() : scalec.f90
- sclstt() : statc.f90
- scmvm() : scmvm.f90
- series() : series.f90
- setdat() : setnm.f90
- setfil() : setnm.f90
- setipr() : setprm.f90
- setmts() : setmts.f90
- setprm() : setprm.f90
- setspc() : setspc.f90
- setxpts() : pltx.c
- sglint() : getdat.f90
- shiftc() : shiftc.f90
- shtwndws() : pltx_dummy.c , pltx.c
- sigint_handler() : catch.c
- sitec() : sitec.f90
- spcpar() : setprm.f90
- splnay() : getdat.f90
- srchc() : srchc.f90
- sscale() : sscale.f90
- sshift() : sshift.f90
- statc() : statc.f90
- stvect() : stvect.f90
- symmsg() : tensym.f90

### - t -

- tcheck() : tensym.f90
- tdchek() : tdchek.f90
- tdgstt() : statc.f90
- tdsqz() : tdsqz.f90
- testmods() : testmods.f90
- toaxil() : tensym.f90
- tocart() : tensym.f90
- tosphr() : tensym.f90
- touppr() : strutl2.f90
- ts() : stats.f90
- twofft() : ftfuns.f90

### - u -

- uncatchc() : catch.c
- ungett() : strutl1.f90

### - v -

- varyc() : varyc.f90

### - w -

- w3j() : w3j.f90
- wig3j() : w3j.f90
- wpoll() : pltx_dummy.c , pltx.c
- wrfun() : writr.f90
- writec() : writec.f90
- wrjac() : writr.f90
- wrspc() : writr.f90
- wrtrdg() : writr.f90
- wtdres() : fitl.f90

### - x -

- xdump() : pltx.c
- xnew() : pltx.c
- xpack() : fitl.f90

### - z -

- zaxpy() : zaxpy.f90
- zaypx() : zaypx.f90
- zbrac() : stats.f90
- zbrent() : stats.f90
- zdotu() : zdotu.f90